<?php

namespace SM\Service;

use SM\Factory\Sm00005000TabParametrizacoesSignatariosPadroesFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00005000TabParametrizacoesSignatariosPadroesService
{
    protected $connection;
    protected $parametrizacaoSignatariosFactory;
    protected $environment;
    protected $newCode;

    public function __construct(Sm00005000TabParametrizacoesSignatariosPadroesFactory $parametrizacaoSignatariosFactory, Environment $environment, NewCode $newCode, EntityManager $entityManager)
    {
        $this->parametrizacaoSignatariosFactory = $parametrizacaoSignatariosFactory;
        $this->environment                      = $environment;
        $this->newCode                          = $newCode;
        $this->connection                       = $entityManager->getConnection();
    }

    public function getSignatariosPadroes()
    {
        $data = $this->parametrizacaoSignatariosFactory->getSignatariosPadroes();
        return $data;
    }

    public function getParceriaOperador()
    {
        $data = $this->parametrizacaoSignatariosFactory->getParceriaOperador();
        return $data;
    }

    public function saveSignatariosPadroes($parametros)
    {
        if ($parametros['IDTPSIGNATARIO'] == "SE") {
            foreach ($parametros['NRPARCNEGOCIO'] as $signatario) {
                $paramsValida = array(
                    "NRSIGNATARIOSPADR"       => $parametros['NRSIGNATARIOSPADR'],
                    "NRPARCNEGOCIO"           => $signatario,
                );
    
                $valor = $this->parametrizacaoSignatariosFactory->validaDuplicadosSignatarios($paramsValida);
            }
            if ($valor[0]["QTD"] > 0) {
                throw new \Exception("EXISTE");
            }
        } else {
            $paramsValida = array(
                "NRSIGNATARIOSPADR"       => $parametros['NRSIGNATARIOSPADR'],
                "IDTPSIGNATARIO"          => $parametros['IDTPSIGNATARIO'],
            );
            $valor = $this->parametrizacaoSignatariosFactory->validaDuplicadosTpSignatarios($paramsValida);
            if ($valor[0]["QTD"] > 0) {
                throw new \Exception("EXISTE");
            }
        }

        $this->connection->beginTransaction();
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        try {
            $dsemailnotsigenv = implode("_", $parametros['DSEMAILNOTSIGNENV']);
            if ($parametros['NRSIGNATARIOSPADR'] == null) {
                if (!empty($parametros['NRPARCNEGOCIO'])) {
                    foreach ($parametros['NRPARCNEGOCIO'] as $signatario) {
                        $nrsignatariospadr = $this->newCode->getCodeByTableName("FCT_SIGNATARIOSPADR", $nrorg, 1, 10, true);
                        $dataInsertSignatario = array(
                            "NRSIGNATARIOSPADR"     => $nrsignatariospadr,
                            "NRPARCNEGOCIO"         => $signatario,
                            "IDTIPOASSINATURA"      => $parametros['IDTIPOASSINATURA'],
                            "IDTESTEMUNHA"          => $parametros['IDTESTEMUNHA'],
                            "NRORDENACAO"           => $parametros['NRORDENACAO'],
                            "IDINSERCAOAUTO"        => $parametros['IDINSERCAOAUTO'],
                            "NRORG"                 => $nrorg,
                            "CDOPERINCLUSAO"        => $cdoperador,
                            "IDATIVO"               => "S",
                            "IDTPSIGNATARIO"        => $parametros['IDTPSIGNATARIO'],
                            "DSEMAILNOTSIGNENV"     => $dsemailnotsigenv,
                            "DSEMAILNOTIFOUTROS"    => $parametros['DSEMAILNOTIFOUTROS'],
                        );
                        $this->parametrizacaoSignatariosFactory->insertSignatariosPadrao($dataInsertSignatario);
                        if (!empty($parametros['OPERADORES'])) {
                            $operadores = implode("_", $parametros['OPERADORES']);
                            $this->insereOperadoresNotifica($nrsignatariospadr, $operadores);
                        }
                    }
                } else {
                    $nrsignatariospadr = $this->newCode->getCodeByTableName("FCT_SIGNATARIOSPADR", $nrorg, 1, 10, true);
                    $dataInsertSignatario = array(
                        "NRSIGNATARIOSPADR"     => $nrsignatariospadr,
                        "NRPARCNEGOCIO"         => null,
                        "IDTIPOASSINATURA"      => $parametros['IDTIPOASSINATURA'],
                        "IDTESTEMUNHA"          => $parametros['IDTESTEMUNHA'],
                        "NRORDENACAO"           => $parametros['NRORDENACAO'],
                        "IDINSERCAOAUTO"        => $parametros['IDINSERCAOAUTO'],
                        "NRORG"                 => $nrorg,
                        "CDOPERINCLUSAO"        => $cdoperador,
                        "IDATIVO"               => "S",
                        "IDTPSIGNATARIO"        => $parametros['IDTPSIGNATARIO'],
                        "DSEMAILNOTSIGNENV"     => $dsemailnotsigenv,
                        "DSEMAILNOTIFOUTROS"    => $parametros['DSEMAILNOTIFOUTROS'],
                    );
                    $this->parametrizacaoSignatariosFactory->insertSignatariosPadrao($dataInsertSignatario);
                    if (!empty($parametros['OPERADORES'])) {
                        $operadores = implode("_", $parametros['OPERADORES']);
                        $this->insereOperadoresNotifica($nrsignatariospadr, $operadores);
                    }
                }
            } else {
                $dataUpdateSignatario = array(
                    "NRSIGNATARIOSPADR"     => $parametros['NRSIGNATARIOSPADR'],
                    "IDTIPOASSINATURA"      => $parametros['IDTIPOASSINATURA'],
                    "IDTESTEMUNHA"          => $parametros['IDTESTEMUNHA'],
                    "NRORDENACAO"           => $parametros['NRORDENACAO'],
                    "IDINSERCAOAUTO"        => $parametros['IDINSERCAOAUTO'],
                    "NRORG"                 => $nrorg,
                    "CDOPERULTATU"          => $cdoperador,
                    "IDATIVO"               => "S",
                    "IDTPSIGNATARIO"        => $parametros['IDTPSIGNATARIO'],
                    "DSEMAILNOTSIGNENV"     => $dsemailnotsigenv,
                    "DSEMAILNOTIFOUTROS"    => $parametros['DSEMAILNOTIFOUTROS'],
                );
                $this->parametrizacaoSignatariosFactory->updateSignatariosPadrao($dataUpdateSignatario);
                if (!empty($parametros['OPERADORES'])) {
                    $operadores = implode("_", $parametros['OPERADORES']);
                    $this->insereOperadoresNotifica($parametros['NRSIGNATARIOSPADR'], $operadores);
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function insereOperadoresNotifica($nrsignatariospadr, $operadores)
    {
        $this->connection->beginTransaction();
        $nrorg = $this->environment->getNrOrg();
        $cdoperador = $this->environment->getCdOperador();

        try {
            $params = array(
                "NRSIGNATARIOSPADR" => $nrsignatariospadr,
                "NRORG"             => $nrorg
            );
            
            $this->parametrizacaoSignatariosFactory->deletaOperadoresNotifica($params);
            
            $operadoresAux = explode('_', $operadores);
                
            foreach ($operadoresAux as $cdoperdor) {
                $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
            
                $params = array(
                    "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                    "NRSIGNATARIOSPADR"    => $nrsignatariospadr,
                    "CDOPERADOR"           => $cdoperdor,
                    "NRORG"                => $nrorg,
                    "OPERADOR"             => $cdoperador
                );
                $this->parametrizacaoSignatariosFactory->insereOperadoresNotifica($params);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteParametrosSignatario($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros as $parametroSignatario) {
                $dataParam = array( "NRSIGNATARIOSPADR" => $parametroSignatario["NRSIGNATARIOSPADR"],);
                $this->parametrizacaoSignatariosFactory->deleteParametrosSignatario($dataParam);
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function cadAutoSignatPadr($row)
    {
        try {
            $nrorg = $this->environment->getNrOrg();
            $operador = $this->environment->getCdOperador();
            $this->connection->beginTransaction();
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->parametrizacaoSignatariosFactory->validaTokenCertsign($params);
            if (count($certsign[0]) > 0) {
                $idtipoassinatura = $row["IDTIPOASSINATURA"];
                $idtestemunha = $row["IDTESTEMUNHA"];
                $nrordenacao = $row["NRORDENACAO"];
                $idinsercaoauto = $row["IDINSERCAOAUTO"];
                $signatarios = $row["NRPARCNEGOCIO"];
                
                if (isset($row["DSEMAILNOTSIGNENV"])) {
                    $dsemailnotsigenv = implode('_', $row["DSEMAILNOTSIGNENV"]);
                } else {
                    $dsemailnotsigenv = null;
                }
                
                if (isset($row["OPERADORES"])) {
                    $operadores = $row["OPERADORES"];
                } else {
                    $operadores = null;
                }
                
                if (isset($row["DSEMAILNOTIFOUTROS"])) {
                    $dsemailnotifoutros = $row["DSEMAILNOTIFOUTROS"];
                } else {
                    $dsemailnotifoutros = null;
                }
                
                if (count($signatarios) > 0) {
                    foreach ($signatarios as $signatario) {
                        $params = array(
                            "NRPARCNEGOCIO"  => $signatario,
                            "IDTPSIGNATARIO" => "SE",
                            "NRORG"          => $nrorg
                        );
                        $valida = $this->parametrizacaoSignatariosFactory->validaSignatCadastrados($params);
                        if ($valida[0]["VALIDA"] == 0) {
                            $nrsignatariospadr = $this->newCode->getCodeByTableName("FCT_SIGNATARIOSPADR", $nrorg, 1, 10, true);
                            $params= array(
                                "NRSIGNATARIOSPADR"  => $nrsignatariospadr,
                                "NRPARCNEGOCIO"      => $signatario,
                                "IDTIPOASSINATURA"   => $idtipoassinatura,
                                "IDTESTEMUNHA"       => $idtestemunha,
                                "NRORDENACAO"        => $nrordenacao,
                                "IDINSERCAOAUTO"     => $idinsercaoauto,
                                "DSEMAILNOTSIGNENV"  => $dsemailnotsigenv,
                                "DSEMAILNOTIFOUTROS" => $dsemailnotifoutros,
                                "NRORG"              => $nrorg,
                                "OPERADOR"           => $operador
                            );
                          
                            $this->parametrizacaoSignatariosFactory->insereSignatariosPadroesCadAuto($params);
                          
                            if ($operadores != null) {
                                foreach ($operadores as $cdoperador) {
                                    $nrrelopernotifassele = $this->newCode->getCodeByTableName("FCT_RELACOPERNOTIFASSELE", $nrorg, 1, 10, true);
                                    $params = array(
                                       "NRRELOPERNOTIFASSELE" => $nrrelopernotifassele,
                                       "NRSIGNATARIOSPADR"    => $nrsignatariospadr,
                                       "CDOPERADOR"           => $cdoperador,
                                       "NRORG"                => $nrorg,
                                       "OPERADOR"             => $operador
                                    );
                                    $this->parametrizacaoSignatariosFactory->insereOperadoresNotifica($params);
                                }
                            }
                        }
                    }
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
}
