import {
    DateRange, Form, Modal, ModalService, Select, Tabs,
} from '@zeedhi/common';
import { Metadata } from '@zeedhi/core';
import { TekGrid, TekTreeGrid } from '@zeedhi/teknisa-components-common';

export class Sm00001101RelatorioCustomizavelPropostaController {
    private FilterModal!: Modal;

    public campoModal: any = {};

    public setFilterElementoRelatorioCustomizavelProposta({ component }: any) {
        component.datasource.setFilter({
            IDATIVO: 'S',
        });
    }

    public async abrirModalFilterRelatorioProposta() {
        if (!this.FilterModal) {
            this.FilterModal = await ModalService.createFromJson('sm_00001_101_relatorio_customizavel_proposta/modal/filtro_00001_101_relatorio_customizavel_proposta', true);
        }
        await this.FilterModal.show();
        setTimeout(() => {
            Metadata.getInstance<Select>('formDadosPropostaRelatorio-NRSEQORCAMENTO').value = this.campoModal.nrseqorcamento || null;
            Metadata.getInstance<Select>('formDadosPropostaRelatorio-NRPARCNEGOCIO').value = this.campoModal.nrparcnegocio || null;
            Metadata.getInstance<DateRange>('formDadosPropostaRelatorio-DTREFORCAMENTO').value = this.campoModal.dtreforcamento || null;
            Metadata.getInstance<Select>('formDadosPropostaRelatorio-IDSITUACAOORCAMENTO').value = this.campoModal.idsituacaoorcamento || null;
            Metadata.getInstance<Select>('formDadosPropostaRelatorio-CDFILIAL').value = this.campoModal.cdfilial || null;
            Metadata.getInstance<DateRange>('formDadosPropostaRelatorio-DTACEITEORCA').value = this.campoModal.dtaceiteorca || null;
            Metadata.getInstance<Select>('formDadosPropostaRelatorio-NMORCAMENTOMODELO').value = this.campoModal.nmorcamentomodelo || null;
            Metadata.getInstance<Select>('formDadosPropostaRelatorio-NRTIPOORCAMENTO').value = this.campoModal.nrtipoorcamento || null;
            Metadata.getInstance<Select>('formDadosPropostaRelatorio-CDOPERRESPONSAVEL').value = this.campoModal.cdoperresponsavel || null;
            Metadata.getInstance<Select>('formDadosServicoRelatorio-CDSERVORCA').value = this.campoModal.cdservorca || null;
            Metadata.getInstance<Select>('formDadosServicoRelatorio-IDELEMENTO').value = this.campoModal.idelemento || null;
            Metadata.getInstance<Select>('formDadosServicoRelatorio-CDTPMEDIDASERV').value = this.campoModal.cdtpmedidaserv || null;
            Metadata.getInstance<Select>('formDadosInterlocutorRelatorio-NRSEQINTERLOCUTOR').value = this.campoModal.nrseqinterlocutor || null;
            Metadata.getInstance<Select>('formDadosAdicionaisRelatorio-NRSEQOPORT').value = this.campoModal.nrseqport || null;
            Metadata.getInstance<Select>('formDadosAdicionaisRelatorio-NRVENDEDOR').value = this.campoModal.nrvendedor || null;
        }, 1000);
    }

    public fecharModalFilterRelatorioProposta() {
        this.FilterModal.hide();
    }

    public destruirModal() {
        this.FilterModal?.destroy();
    }

    public eventFilterPropostaRelatorio({ event }: any) {
        event.preventDefault();
        this.abrirModalFilterRelatorioProposta();
    }

    public limparCampos() {
        Metadata.getInstance<Form>('formDadosPropostaRelatorio').clearForm();
        Metadata.getInstance<Form>('formDadosServicoRelatorio').clearForm();
        Metadata.getInstance<Form>('formDadosInterlocutorRelatorio').clearForm();
        Metadata.getInstance<Form>('formDadosAdicionaisRelatorio').clearForm();

        this.campoModal = {
            nrseqorcamento: null,
            nrparcnegocio: null,
            dtreforcamento: null,
            idsituacaoorcamento: null,
            cdfilial: null,
            dtaceiteorca: null,
            nmorcamentomodelo: null,
            nrtipoorcamento: null,
            cdoperresponsavel: null,
            cdservorca: null,
            idelemento: null,
            cdtpmedidaserv: null,
            nrseqinterlocutor: null,
            nrseqport: null,
            nrvendedor: null,
        };

        this.filtroTabItens = {
            NRSEQORCAMENTO: null,
            NRPARCNEGOCIO: null,
            CDSERVORCA: null,
            IDELEMENTO: null,
        };
    }

    public expandirRelatorioProposta({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;

        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public filterGridsRelatorioProposta() {
        const gridProposta = Metadata.getInstance<TekGrid>('grid-tab-proposta-relatorio');

        this.campoModal = {
            nrseqorcamento: Metadata.getInstance<Select>('formDadosPropostaRelatorio-NRSEQORCAMENTO').value,
            nrparcnegocio: Metadata.getInstance<Select>('formDadosPropostaRelatorio-NRPARCNEGOCIO').value,
            dtreforcamento: Metadata.getInstance<DateRange>('formDadosPropostaRelatorio-DTREFORCAMENTO').value,
            idsituacaoorcamento: Metadata.getInstance<Select>('formDadosPropostaRelatorio-IDSITUACAOORCAMENTO').value,
            cdfilial: Metadata.getInstance<Select>('formDadosPropostaRelatorio-CDFILIAL').value,
            dtaceiteorca: Metadata.getInstance<DateRange>('formDadosPropostaRelatorio-DTACEITEORCA').value,
            nmorcamentomodelo: Metadata.getInstance<Select>('formDadosPropostaRelatorio-NMORCAMENTOMODELO').value,
            nrtipoorcamento: Metadata.getInstance<Select>('formDadosPropostaRelatorio-NRTIPOORCAMENTO').value,
            cdoperresponsavel: Metadata.getInstance<Select>('formDadosPropostaRelatorio-CDOPERRESPONSAVEL').value,
            cdservorca: Metadata.getInstance<Select>('formDadosServicoRelatorio-CDSERVORCA').value,
            idelemento: Metadata.getInstance<Select>('formDadosServicoRelatorio-IDELEMENTO').value,
            cdtpmedidaserv: Metadata.getInstance<Select>('formDadosServicoRelatorio-CDTPMEDIDASERV').value,
            nrseqinterlocutor: Metadata.getInstance<Select>('formDadosInterlocutorRelatorio-NRSEQINTERLOCUTOR').value,
            nrseqport: Metadata.getInstance<Select>('formDadosAdicionaisRelatorio-NRSEQOPORT').value,
            nrvendedor: Metadata.getInstance<Select>('formDadosAdicionaisRelatorio-NRVENDEDOR').value,
        };

        gridProposta.datasource.setFilter({
            NRSEQORCAMENTO: this.campoModal.nrseqorcamento,
            NRPARCNEGOCIO: this.campoModal.nrparcnegocio,
            DTREFORCAMENTO: this.campoModal.dtreforcamento,
            IDSITUACAOORCAMENTO: this.campoModal.idsituacaoorcamento,
            CDFILIAL: this.campoModal.cdfilial,
            DTACEITEORCA: this.campoModal.dtaceiteorca,
            NRORCAMENTOMODELO: this.campoModal.nmorcamentomodelo,
            NRTIPOORCAMENTO: this.campoModal.nrtipoorcamento,
            CDOPERRESPONSAVEL: this.campoModal.cdoperresponsavel,
            CDSERVORCA: this.campoModal.cdservorca,
            IDELEMENTO: this.campoModal.idelemento,
            CDTPMEDIDASERV: this.campoModal.cdtpmedidaserv,
            NRSEQINTERLOCUTOR: this.campoModal.nrseqinterlocutor,
            NRSEQOPORT: this.campoModal.nrseqport,
            NRVENDEDOR: this.campoModal.nrvendedor,

        });

        this.filtroTabItens = {
            NRSEQORCAMENTO: this.campoModal.nrseqorcamento,
            NRPARCNEGOCIO: this.campoModal.nrparcnegocio,
            CDSERVORCA: this.campoModal.cdservorca,
            IDELEMENTO: this.campoModal.idelemento,
            CDTPMEDIDASERV: this.campoModal.cdtpmedidaserv,
        };

        this.fecharModalFilterRelatorioProposta();
    }

    protected filtroTabItens: any;

    public filtrarTabItens() {
        const tab = Metadata.getInstance<Tabs>('tabPrincipalRelatorioProposta');

        if (tab.tabs[tab.activeTab].name === 'tab_itens') {
            if (this.filtroTabItens !== undefined) {
                if (this.filtroTabItens?.NRSEQORCAMENTO.length !== 0 || this.filtroTabItens?.NRPARCNEGOCIO.length !== 0
                    || this.filtroTabItens?.CDSERVORCA.length !== 0 || this.filtroTabItens?.CDTPMEDIDASERV.length !== 0 || this.filtroTabItens?.IDELEMENTO !== null) {
                    setTimeout(() => {
                        const gridItens = Metadata.getInstance<TekTreeGrid>('tek-grid-tab-itens');
                        gridItens.datasource.setFilter({
                            NRSEQORCAMENTO: this.filtroTabItens?.NRSEQORCAMENTO,
                            NRPARCNEGOCIO: this.filtroTabItens?.NRPARCNEGOCIO,
                            CDSERVORCA: this.filtroTabItens?.CDSERVORCA,
                            IDELEMENTO: this.filtroTabItens?.IDELEMENTO,
                            CDTPMEDIDASERV: this.filtroTabItens?.CDTPMEDIDASERV,
                        });
                    }, 1000);
                }
            }
        }
    }
}
